SdkCallbacks class

Constructors

SdkCallbacks({dynamic onSuccess({required String message, required String status})?, dynamic onFailure({required String message, required String status})?, dynamic onClose({required String message, required String status})?})

Properties

hashCode int
The hash code for this object.
no setterinherited
onClose → dynamic Function({required String message, required String status})?
final
onFailure → dynamic Function({required String message, required String status})?
final
onSuccess → dynamic Function({required String message, required String status})?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited