SdkUserModel class

Constructors

SdkUserModel({String? accessToken, String? orderAccessToken, String? tokenType, String? refreshToken, num? expiresIn, String? scope, String? id, String? orderUserId, String? accountId, List<Profile>? profiles, String? version, List<String>? roles, String? fullName, String? phoneNumber, String? userProfileId, String? clientId, String? clientSecret})
SdkUserModel.fromJson(Map<String, dynamic> json)
factory

Properties

accessToken ↔ String?
getter/setter pair
accountId ↔ String?
getter/setter pair
clientId ↔ String?
getter/setter pair
clientSecret ↔ String?
getter/setter pair
expiresIn ↔ num?
getter/setter pair
fullName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
orderAccessToken ↔ String?
getter/setter pair
orderUserId ↔ String?
getter/setter pair
phoneNumber ↔ String?
getter/setter pair
profiles ↔ List<Profile>?
getter/setter pair
refreshToken ↔ String?
getter/setter pair
roles ↔ List<String>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String?
getter/setter pair
tokenType ↔ String?
getter/setter pair
userProfileId ↔ String?
getter/setter pair
version ↔ String?
getter/setter pair

Methods

copyWith({String? accessToken, String? orderAccessToken, String? tokenType, String? refreshToken, num? expiresIn, String? scope, String? id, String? orderUserId, String? accountId, List<Profile>? profiles, String? version, List<String>? roles, String? fullName, String? phoneNumber, String? userProfileId, String? clientId, String? clientSecret}) → SdkUserModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited