Address class

Constructors

Address({String? addressLine1, String? addressLine2, String? city, String? state, String? pincode})
Address.fromJson(Map<String, dynamic> json)
factory

Properties

addressLine1 String?
getter/setter pair
addressLine2 String?
getter/setter pair
city String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pincode String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited