NotificationDataResponse class

Constructors

NotificationDataResponse({String? id, String? billId, String? title, String? subtitle, String? imageUrl, String? type, String? param, String? workFlowName, String? sessionId, String? invoiceId, String? profileId})
NotificationDataResponse.fromJson(Map<String, dynamic> json)
factory

Properties

billId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
imageUrl ↔ String?
getter/setter pair
invoiceId ↔ String?
getter/setter pair
param ↔ String?
getter/setter pair
profileId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId ↔ String?
getter/setter pair
subtitle ↔ String?
getter/setter pair
title ↔ String?
getter/setter pair
type ↔ String?
getter/setter pair
workFlowName ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited