Payload class

Constructors

Payload({bool? show, String? landingType, num? availableCreditLimit, num? creditLimit, num? totalOutstanding, num? lockedAmt, String? panNumber, String? channel, Token? token, String? requestId, String? userId, String? accId, String? puId, String? proposalId})
Payload.fromJson(Map<String, dynamic> json)
factory

Properties

accId ↔ String?
getter/setter pair
availableCreditLimit ↔ num?
getter/setter pair
channel ↔ String?
getter/setter pair
creditLimit ↔ num?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
landingType ↔ String?
getter/setter pair
lockedAmt ↔ num?
getter/setter pair
panNumber ↔ String?
getter/setter pair
proposalId ↔ String?
getter/setter pair
puId ↔ String?
getter/setter pair
requestId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
show ↔ bool?
getter/setter pair
token ↔ Token?
getter/setter pair
totalOutstanding ↔ num?
getter/setter pair
userId ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited