Token class

Constructors

Token({String? accessToken, String? tokenType, String? refreshToken, String? expiresIn, String? scope, String? id, List<String>? roles, String? version})
Token.fromJson(Map<String, dynamic> json)
factory

Properties

accessToken ↔ String?
getter/setter pair
expiresIn ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
refreshToken ↔ String?
getter/setter pair
roles ↔ List<String>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String?
getter/setter pair
tokenType ↔ String?
getter/setter pair
version ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited