Images class

Constructors

Images()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

applyCoupon → const String
arrowForward → const String
availCredit → const String
bank → const String
bbps → const String
bell → const String
bharatConnect → const String
bills → const String
brandSort → const String
business → const String
calendar → const String
call → const String
camera → const String
cancel → const String
close → const String
coinEarned → const String
coinPending → const String
coinRedeemed → const String
coins → const String
compliant → const String
contactHelp → const String
copy → const String
copy2 → const String
coupon → const String
coupons → const String
credit → const String
creditClicked → const String
creditDetailInvoice → const String
creditDetailRepayment → const String
dashboard → const String
delete → const String
directorPerson → const String
discount → const String
document → const String
documents → const String
done → const String
easyApplication → const String
edit → const String
email → const String
enterName → const String
exit → const String
failed → const String
failedFilled → const String
fastag → const String
flag → const String
growBusiness → const String
gst → const String
gstDocument → const String
headset → const String
help → const String
helpAndSupport → const String
hidden → const String
history → const String
historyClicked → const String
historyIcon → const String
home → const String
homeClicked → const String
homeNotification → const String
introFirst → const String
introSecond → const String
introThird → const String
invoices → const String
itr → const String
kred_background → const String
kredcoin2 → const String
kredcoins → const String
kredmint → const String
loans → const String
loansClicked → const String
logout → const String
mail → const String
more → const String
myCoupon → const String
nickname → const String
noBellNotifications → const String
notification → const String
offer → const String
offerClicked → const String
orderSuccess → const String
organization → const String
otp → const String
panDocument → const String
panExit → const String
paybill → const String
paymentCancelled → const String
paymentDone → const String
paymentDoneFilled → const String
paymentPending → const String
phone → const String
privacy → const String
privacyIntro → const String
privacyPolicy → const String
productPlaceholder → const String
profile → const String
promoter → const String
rate → const String
rbi → const String
recentInvoice → const String
recentRepayment → const String
refund → const String
repayment → const String
restaurantFallback → const String
rightArrow → const String
safe_secure → const String
secure → const String
share → const String
success → const String
systemLogout → const String
termAndConditions → const String
terms → const String
upload → const String
user → const String
voucher → const String
whatsapp → const String
work → const String