ErrorMessages class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- accountInvalid → const String
- accountRequired → const String
- amountIsRequired → const String
- bankAccountNumberIsRequired → const String
- bankNameRequired → const String
- couponCodeIsRequired → const String
- emailInvalid → const String
- errorUploadingInvoice → const String
- fullNameRequired → const String
- gstNumberIsRequired → const String
- ifscCodeIsRequired → const String
- ifscInvalid → const String
- ifscRequired → const String
- invalidInput → const String
- invalidPan → const String
- mobileInvalid → const String
- mobileNumberIsRequired → const String
- networkGeneral → const String
- noCouponFound → const String
- noDataFound → const String
- noHistoryFound → const String
- noInvoicesFound → const String
- noNotifications → const String
- noPlanFound → const String
- noRepaymentsFound → const String
- noSupplierFound → const String
- noVouchersFound → const String
- otpIsInvalid → const String
- pleaseUploadInvoiceDocument → const String
- providedDobDoesNotAlignsWithPan → const String
- providedNameDoesNotAlignsWithPan → const String
- residenceIsRequired → const String
- thisFieldIsRequired → const String