CommonMethod class

Constructors

CommonMethod()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getKeyboardTypeFromRegex(String? regex) TextInputType
getStateCityFromAddressResponse({required AddressDetailResponse? addressDetailResponse}) Future<Map<String, String>?>
isKeyboardVisible(BuildContext context) bool
millisecondsToMinutes(num milliseconds) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseDate({required String date}) DateTime?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getCompressedUrl({required String? originalImageUrl, required String imageHeight, int dpr = 5}) String