LoadingUtils class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
hideLoader()
→ void
-
Hide loader
-
showLoader({String title = Strings.justAMoment, String subtitle = Strings.processingYourRequest})
→ void
-
Show loader