CustomButton class

Inheritance

Constructors

CustomButton({Key? key, String? buttonText, required VoidCallback onTap, Color? buttonColor, double? width, TextStyle? buttonTextStyle, Widget? icon, BorderRadius? buttonRadius, EdgeInsets? buttonPadding, Widget? suffixWidget, Color? borderColor, Widget? prefixWidget, double textPadding = 0.0, double borderWidth = 1.5, bool disabled = false, double suffixPadding = 21, MainAxisSize? mainAxisSize, double prefixWidgetPadding = 5, bool loading = false})
const

Properties

borderColor → Color?
final
borderWidth → double
final
buttonColor → Color?
final
buttonPadding → EdgeInsets?
final
buttonRadius → BorderRadius?
final
buttonText → String?
final
buttonTextStyle → TextStyle?
final
disabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loading → bool
final
mainAxisSize → MainAxisSize?
final
onTap → VoidCallback
final
prefixWidget → Widget?
final
prefixWidgetPadding → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffixPadding → double
final
suffixWidget → Widget?
final
textPadding → double
final
width → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited