AppState class
Constructors
- AppState({PackageInfo? packageInfo, UserProfileResponse? userProfileResponse, bool? userProfileFetched, bool? isLoading})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLoading → bool?
-
final
- packageInfo → PackageInfo?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userProfileFetched → bool?
-
final
- userProfileResponse → UserProfileResponse?
-
final
Methods
-
copyWith(
{PackageInfo? packageInfo, UserProfileResponse? userProfileResponse, bool? userProfileFetched, bool? isLoading}) → AppState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited