menu
loan_sdk_package package
documentation
app/data/models/dto/user_model.dart
Profile class
Profile class
dark_mode
light_mode
Profile
class
Constructors
Profile
({
String
?
id
,
String
?
lenderId
,
String
?
anchorId
})
Profile.fromJson
(
Map
<
String
,
dynamic
>
json
)
factory
Properties
anchorId
↔
String
?
getter/setter pair
hashCode
→
int
The hash code for this object.
no setter
inherited
id
↔
String
?
getter/setter pair
lenderId
↔
String
?
getter/setter pair
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
copyWith
(
{
String
?
id
,
String
?
lenderId
,
String
?
anchorId
})
→
Profile
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Map
<
String
,
dynamic
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
loan_sdk_package package
documentation
app/data/models/dto/user_model
Profile class
user_model library