SdkRequest class

Constructors

SdkRequest({String? username, String? source, String? program, String? requestId, String? puId, String? policyNo, String? anchorId, String? channel, String? version, UserContext? userContext, ClientMeta? clientMeta, String? clientId, String? clientSecret, Theme? theme})
SdkRequest.fromJson(Map<String, dynamic> json)
factory

Properties

anchorId ↔ String?
getter/setter pair
channel ↔ String?
getter/setter pair
clientId ↔ String?
getter/setter pair
clientMeta ↔ ClientMeta?
getter/setter pair
clientSecret ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
policyNo ↔ String?
getter/setter pair
program ↔ String?
getter/setter pair
puId ↔ String?
getter/setter pair
requestId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ String?
getter/setter pair
theme ↔ Theme?
getter/setter pair
userContext ↔ UserContext?
getter/setter pair
username ↔ String?
getter/setter pair
version ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited