UserContext class

Constructors

UserContext({String? pancard, String? fullName, String? gender, String? email, DateTime? dob, Address? address})
UserContext.fromJson(Map<String, dynamic> json)
factory

Properties

address Address?
getter/setter pair
dob DateTime?
getter/setter pair
email String?
getter/setter pair
fullName String?
getter/setter pair
gender String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pancard String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited