panTermAndCondition1 constant
String
const panTermAndCondition1
Implementation
static const String panTermAndCondition1 =
"I confirm the above pan belongs to me. I authorize the lender/lending partners on KredMint app to pull my records from CKYCR, run credit checks on my behalf, obtain my report and share the report with other lending partners.";