Urls class

Constructors

Urls()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

accounts({required String userId, required String subType, required String baseUrlType}) → String
accountsV2({required String userId, required String subType, required String baseUrlType}) → String
addItemInCart({required String cartId, required String baseUrlType}) → dynamic
appConfig({required String baseUrlType}) → String
applyBbpsCoupon({required String baseUrlType, required String userId, required String userBillId}) → String
applyCoupon({required String baseUrlType}) → String
applyOrderCoupon({required String baseUrlType, required String cartId}) → String
bank({required String baseUrlType}) → String
bellNotification({required String baseUrlType}) → String
bill({required String baseUrlType, required String userId, required String id}) → String
billV2({required String baseUrlType, required String userId, required String id}) → String
cart({required String baseUrlType, required String userId}) → dynamic
checkToken({required String baseUrlType}) → String
couponList({required String baseUrlType}) → dynamic
createSupplier({required String baseUrlType}) → String
deleteDocument({required String baseUrlType}) → String
eligibility({required String baseUrlType}) → String
fetchAccountBill({required String userId, required String accId, required String baseUrlType}) → String
fetchBill({required String userId, required String baseUrlType}) → String
fetchBillV2({required String userId, required String baseUrlType}) → String
footerNotification({required String baseUrlType}) → String
getAllCoupons({required String baseUrlType}) → String
getCompressionUrl({required int dpr, required String height}) → String
getCouponBrands({required String baseUrlType, String? query}) → String
getCouponCategoryName({required String baseUrlType}) → String
getCouponStatusName({required String baseUrlType}) → String
getCreditDrawdown({required String baseUrlType, required String profileId}) → String
getInvoiceList({required String baseUrlType, required String profileId, String? query}) → String
getKfs({required String baseUrlType, required String userId}) → String
getOperatorList({required String subType, required String baseUrlType}) → String
getOperatorListV2({required String subType, required String baseUrlType}) → String
getOrderStatus({required String baseUrlType, required String orderId}) → dynamic
getOtp({required String baseUrlType}) → String
getPaymentAccessKey({required String baseUrlType}) → String
getPaymentAccessKeyV2({required String baseUrlType}) → String
getPaymentStatus({required String mbTxnId, required String baseUrlType}) → String
getPrimaryRetailerAddress({required String baseUrlType, required String userId}) → dynamic
getRepaymentDue({required String baseUrlType, required String payId, String? query}) → String
getRepaymentList({required String baseUrlType, required String profileId, String? query}) → String
getRetailerAddress({required String baseUrlType, required String userId}) → dynamic
getSupplier({required String baseUrlType}) → dynamic
getSupplierList({required String baseUrlType, required String profileId}) → String
getSupplierProduct({required String baseUrlType, required String supplierId}) → dynamic
getUserCoupons({required String baseUrlType, required String userId}) → String
history({required String baseUrlType}) → String
historyDetail({required String baseUrlType, required String id}) → String
initiateCKyc({required String baseUrlType}) → String
invoiceDetail({required String baseUrlType}) → String
kredcoinHistory({required String baseUrlType, required String userId}) → String
kredcoinWallet({required String baseUrlType, required String userId}) → String
layout({required String pageId, required String baseUrlType}) → dynamic
layoutPage({required String baseUrlType}) → String
leadDashboard({required String baseUrlType}) → String
leadData({required String baseUrlType}) → String
leadNotifications({required String baseUrlType}) → String
leadProfile({required String baseUrlType}) → String
loi({required String baseUrlType}) → String
markAsReadNotification({required String baseUrlType}) → String
mobileOperator({required String opId}) → String
myCoupon({required String baseUrlType}) → String
myCouponDetail({required String baseUrlType, required String myCouponId}) → String
myCouponList({required String baseUrlType, required String userId, String? query}) → String
myCouponStats({required String baseUrlType, required String userId, String? query}) → String
netbanking({required String baseUrlType}) → String
offerDetail({required String baseUrlType}) → String
order({required String baseUrlType}) → dynamic
orderConfig({required String baseUrlType}) → String
orderType({required String baseUrlType}) → String
pay({required String baseUrlType}) → String
paymentMethod({required String baseUrlType}) → String
payOrder({required String baseUrlType, String? query}) → dynamic
pgPay({required String baseUrlType}) → String
plans({required String baseUrlType}) → String
plansV2({required String baseUrlType}) → String
planTypes({required String baseUrlType}) → String
planTypesV2({required String baseUrlType}) → String
rechargeCircle({required String baseUrlType}) → String
rechargeCircleV2({required String baseUrlType}) → String
redeemFreeCoupon({required String baseUrlType}) → String
redeemKredcoin({required String baseUrlType, String? query}) → dynamic
removeCoupon({required String baseUrlType, required String cartId}) → dynamic
repaymentNotification({required String baseUrlType}) → String
report({required String baseUrlType}) → String
searchProduct({required String baseUrlType}) → dynamic
settlement({required String baseUrlType}) → String
softScore({required String baseUrlType}) → String
syncPan({required String baseUrlType}) → String
updateOrderStatus({required String baseUrlType, required String orderId}) → dynamic
updatePaymentStatus({required String baseUrlType}) → String
updateRetailerAddress({required String baseUrlType, required String userId, String? query}) → dynamic
updateUserProfileStage({required String baseUrlType}) → String
uploadDocument({required String baseUrlType}) → String
uploadDrawdownInvoice({required String baseUrlType, required String profileId}) → String
uploadInvoice({required String baseUrlType}) → String
user({required String baseUrlType}) → String
userDevice({required String baseUrlType}) → String
userLimit({required String baseUrlType}) → String
userProfilePage({required String baseUrlType}) → String
validateBank({required String baseUrlType}) → String
validateCKyc({required String baseUrlType}) → String
validateCouponCode({required String baseUrlType, required String userId, required String userBillId}) → String
validateGst({required String baseUrlType}) → String
validateIfsc({required String baseUrlType, required String ifsc}) → String
validatePan({required String baseUrlType}) → String
validatePlan({required String userId, required String baseUrlType}) → String
validatePlanV2({required String userId, required String baseUrlType}) → String
verifyEsign({required String baseUrlType}) → String
verifyMandate({required String baseUrlType}) → String
verifyOtp({required String baseUrlType}) → String
verifyWorkflow({required String baseUrlType}) → String

Constants

getAddressDetail → const String