LoadingUtils class

Constructors

LoadingUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

isLoading → bool
no setter

Static Methods

hideLoader() → void
Hide loader
showLoader({String title = Strings.justAMoment, String subtitle = Strings.processingYourRequest}) → void
Show loader