CommonWidget class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
customAppBar({String? title, Widget? titleWidget, String? subTitle, List<Widget>? suffixWidget, VoidCallback? onBackPressed, TextStyle? titleStyle, Color? backgroundColor = AppColors.white, bool centerTitle = false, bool hideLeading = false, dynamic bottom, Color? leadingIconColor, Widget? leadingWidget, double? titleLeftPadding})
→ PreferredSizeWidget
-
-
customDialog({required BuildContext context, required String heading, required String subHeading, required VoidCallback onOkTap, VoidCallback? onCancelTap, String? okButtonText, String? cancelButtonText, bool barrierDismissible = true})
→ void
-
-
customTile({required dynamic onTap({required String key, required String value}), required String? key, required String? value, String? selectedValue})
→ Widget
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
showOptionBottomSheet({required BuildContext context, required List<Map<String, String>>? options, required dynamic onTap({required String key, required String value}), required String heading, String? value, ValueChanged<String>? onSearchChanged})
→ void
-
-
showSearchableOptionsSheet({required BuildContext context, required String heading, required Widget optionsBuilder(BuildContext context), required dynamic onSearchChanged(String), String? selectedValue})
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited