InputTextField class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- InputTextField
Constructors
-
InputTextField({Key? key, required TextEditingController textFieldWrapper, String? labelText, String? hintText, Widget? prefix, bool readOnly = false, dynamic onChanged(String)?, TextInputType? keyboardType, List<
TextInputFormatter> ? inputFormatters, Widget? suffix, TextStyle? hintStyle, bool capitalize = false, int maxLines = 1, FocusNode? focusNode, Color? borderColor, EdgeInsets? contentPadding, TextAlign? textAlign, double borderRadius = 10, bool autoFocus = false, dynamic onSubmitted(String)?, bool obscureText = false, String errorText = "", int? maxLength, String? validator(String?)?, Color? focusBorderColor, bool? isDense, VoidCallback? onTap, GlobalKey<FormFieldState> ? formFieldKey, TextStyle? labelStyle, TextStyle? textStyle}) -
const
Properties
- autoFocus → bool
-
final
- borderColor → Color?
-
final
- borderRadius → double
-
final
- capitalize → bool
-
final
- contentPadding → EdgeInsets?
-
final
- errorText → String
-
final
- focusBorderColor → Color?
-
final
- focusNode → FocusNode?
-
final
-
formFieldKey
→ GlobalKey<
FormFieldState> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintStyle → TextStyle?
-
final
- hintText → String?
-
final
-
inputFormatters
→ List<
TextInputFormatter> ? -
final
- isDense → bool?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
final
- labelStyle → TextStyle?
-
final
- labelText → String?
-
final
- maxLength → int?
-
final
- maxLines → int
-
final
- obscureText → bool
-
final
- onChanged → dynamic Function(String)?
-
final
- onSubmitted → dynamic Function(String)?
-
final
- onTap → VoidCallback?
-
final
- prefix → Widget?
-
final
- readOnly → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suffix → Widget?
-
final
- textAlign → TextAlign?
-
final
- textFieldWrapper → TextEditingController
-
final
- textStyle → TextStyle?
-
final
- validator → String? Function(String?)?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited